antares.apps.terminal.migrations package
========================================

Submodules
----------

antares.apps.terminal.migrations.0001\_initial module
-----------------------------------------------------

.. automodule:: antares.apps.terminal.migrations.0001_initial
   :members:
   :undoc-members:
   :show-inheritance:

antares.apps.terminal.migrations.0002\_terminallog\_author module
-----------------------------------------------------------------

.. automodule:: antares.apps.terminal.migrations.0002_terminallog_author
   :members:
   :undoc-members:
   :show-inheritance:


Module contents
---------------

.. automodule:: antares.apps.terminal.migrations
   :members:
   :undoc-members:
   :show-inheritance:
